# Asrthon 🔥🟥

**Asrthon** is the loudest and most emotional Python package ever created.

- 🔇 No more boring print.
- 🥀 whisper your pain.
- 🔊 scream your code.
- ❤️ cry if needed.

## Install

```bash
pip install asrthon
